{
    "scan": {
        "analyzer-version-clippy": "1.95.0",
        "analyzer-version-cppcheck": "2.20.0",
        "analyzer-version-gcc": "16.1.1",
        "analyzer-version-gcc-analyzer": "16.1.1",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-129.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20260524.213755.g3c6d0be.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "python-setuptools-82.0.1-1.fc45",
        "store-results-to": "/tmp/tmp25twmvu0/python-setuptools-82.0.1-1.fc45.tar.xz",
        "time-created": "2026-06-01 16:14:21",
        "time-finished": "2026-06-01 16:15:38",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'shellcheck,cppcheck,clippy,unicontrol,gcc' '-o' '/tmp/tmp25twmvu0/python-setuptools-82.0.1-1.fc45.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '--gcc-analyzer-bin=/usr/bin/gcc' '/tmp/tmp25twmvu0/python-setuptools-82.0.1-1.fc45.src.rpm'",
        "tool-version": "csmock-3.8.5.20260529.133039.g6f3b5c6-1.el9"
    },
    "defects": []
}
